@@ -28,7 +28,7 @@ find plugins -iname '*.a'  -delete
 rm -f src/doublecmd.res doublecmd
 rm -f tools/extractdwrflnfo
 rm -f plugins/wcx/zip/lib/ZipConfDlg.lfm
-rm -f plugins/wcx/zip/lib/abresstring.rst
+rm -f plugins/wcx/zip/lib/abresstring.rs?
 rm -f plugins/wfx/ftp/lib/FtpConfDlg.lfm
 rm -f plugins/wfx/samba/lib/smbauthdlg.lfm
 
