@@ -3,9 +3,9 @@
 # This script updates Double Commander Personal Package Archive (PPA) repository
 
 # Set Double Commander version
-DC_VER=0.7.5
+DC_VER=0.7.7
 # Set Ubuntu series
-DISTRO=( wily xenial )
+DISTRO=( xenial yakkety zesty )
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
